<?xml version="1.0"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui library="libktsyndicationplugin" name="syndicationplugin" version="2">

<ToolBar name="SyndicationToolBar"><text>Syndication Toolbar</text>
	<Action name="add_feed"/>
	<Action name="remove_feed"/>
</ToolBar>

</gui>
