<?xml version="1.0"?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui library="libktsearchplugin" name="searchplugin" version="1">
<ToolBar name="SearchToolBar" noEdit="1"><text>Search Toolbar</text>
	<Action name="search_text"/>
	<Action name="search"/>
	<Action name="search_engine_label"/>
	<Action name="search_engine"/>
</ToolBar>
</gui>
